# Image Tagging

This repository contains a plugin that performs image tagging on items in the Pod, or any URL. Internally, the plugin uses a small machine learning classifier trained on ImageNet called [MobileVit](https://huggingface.co/apple/mobilevit-small). This model was chosen as a good balance of speed an accuracy.

# Install

To install as a Python package, run:
```bash
pip install -e .
```

# Run

Make sure you have a pod running. Then, you can run the plugin locally with the run_plugin CLI:

```bash
run_plugin --metadata "metadata.json"
```

## API

The plugin implements 2 endpoints:
- `POST /v1/classify_ids` takes a list of Photo id's in the pod, and tags what object is in each photo. In addition to returning the prediction, it is added to the database.
- `POST /v1/classify_urls` takes a list of web urls of photos, and returns what objects are in each photo

For further information on the API, or to try it out yourself, run the plugin and visit http://0.0.0.0:8009/docs . Note that the port might differ on your machine, it is printed in your commandline when launching the plugin.

# Testing
Unit tests are available in the `tests` folder, and can be run with

```
pytest tests/
```

# Docker

```
docker build -t image_tagging .
```

To run the plugin container:

```
simulate_run_plugin_from_frontend --metadata "metadata.json"
```