from typing import Any, List, Union

from PIL import Image
from transformers import pipeline

DEFAULT_MODEL = "apple/mobilevit-small"

class ImageClassifier:
    def __init__(self, model_name=DEFAULT_MODEL):
        self.model_name = model_name
        self.pipeline = pipeline(task="image-classification", model=model_name)

    def predict(self, images: Union[Image.Image, List[Image.Image]]) -> Any:
        _single_input = False
        if isinstance(images, Image.Image):
            images = [images]
            _single_input = True

        if len(images) == 0:
            return []

        predictions = self.pipeline(images)
        predictions = [prediction[0] for prediction in predictions]

        if _single_input:
            return predictions[0]
        return predictions
